# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
XCAFDimTolObjects module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_xcafdimtolobjects.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _XCAFDimTolObjects
else:
    import _XCAFDimTolObjects

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _XCAFDimTolObjects.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _XCAFDimTolObjects.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XCAFDimTolObjects.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _XCAFDimTolObjects.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _XCAFDimTolObjects.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _XCAFDimTolObjects.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _XCAFDimTolObjects.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _XCAFDimTolObjects.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _XCAFDimTolObjects.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _XCAFDimTolObjects.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XCAFDimTolObjects.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _XCAFDimTolObjects.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _XCAFDimTolObjects.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XCAFDimTolObjects.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _XCAFDimTolObjects.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _XCAFDimTolObjects.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _XCAFDimTolObjects.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _XCAFDimTolObjects:
_XCAFDimTolObjects.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _XCAFDimTolObjects.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *

XCAFDimTolObjects_GeomToleranceType_None = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_None
XCAFDimTolObjects_GeomToleranceType_Angularity = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Angularity
XCAFDimTolObjects_GeomToleranceType_CircularRunout = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_CircularRunout
XCAFDimTolObjects_GeomToleranceType_CircularityOrRoundness = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_CircularityOrRoundness
XCAFDimTolObjects_GeomToleranceType_Coaxiality = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Coaxiality
XCAFDimTolObjects_GeomToleranceType_Concentricity = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Concentricity
XCAFDimTolObjects_GeomToleranceType_Cylindricity = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Cylindricity
XCAFDimTolObjects_GeomToleranceType_Flatness = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Flatness
XCAFDimTolObjects_GeomToleranceType_Parallelism = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Parallelism
XCAFDimTolObjects_GeomToleranceType_Perpendicularity = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Perpendicularity
XCAFDimTolObjects_GeomToleranceType_Position = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Position
XCAFDimTolObjects_GeomToleranceType_ProfileOfLine = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_ProfileOfLine
XCAFDimTolObjects_GeomToleranceType_ProfileOfSurface = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_ProfileOfSurface
XCAFDimTolObjects_GeomToleranceType_Straightness = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Straightness
XCAFDimTolObjects_GeomToleranceType_Symmetry = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_Symmetry
XCAFDimTolObjects_GeomToleranceType_TotalRunout = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceType_TotalRunout
XCAFDimTolObjects_GeomToleranceModif_Any_Cross_Section = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Any_Cross_Section
XCAFDimTolObjects_GeomToleranceModif_Common_Zone = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Common_Zone
XCAFDimTolObjects_GeomToleranceModif_Each_Radial_Element = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Each_Radial_Element
XCAFDimTolObjects_GeomToleranceModif_Free_State = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Free_State
XCAFDimTolObjects_GeomToleranceModif_Least_Material_Requirement = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Least_Material_Requirement
XCAFDimTolObjects_GeomToleranceModif_Line_Element = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Line_Element
XCAFDimTolObjects_GeomToleranceModif_Major_Diameter = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Major_Diameter
XCAFDimTolObjects_GeomToleranceModif_Maximum_Material_Requirement = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Maximum_Material_Requirement
XCAFDimTolObjects_GeomToleranceModif_Minor_Diameter = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Minor_Diameter
XCAFDimTolObjects_GeomToleranceModif_Not_Convex = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Not_Convex
XCAFDimTolObjects_GeomToleranceModif_Pitch_Diameter = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Pitch_Diameter
XCAFDimTolObjects_GeomToleranceModif_Reciprocity_Requirement = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Reciprocity_Requirement
XCAFDimTolObjects_GeomToleranceModif_Separate_Requirement = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Separate_Requirement
XCAFDimTolObjects_GeomToleranceModif_Statistical_Tolerance = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Statistical_Tolerance
XCAFDimTolObjects_GeomToleranceModif_Tangent_Plane = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_Tangent_Plane
XCAFDimTolObjects_GeomToleranceModif_All_Around = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_All_Around
XCAFDimTolObjects_GeomToleranceModif_All_Over = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModif_All_Over
XCAFDimTolObjects_DimensionModif_ControlledRadius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_ControlledRadius
XCAFDimTolObjects_DimensionModif_Square = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_Square
XCAFDimTolObjects_DimensionModif_StatisticalTolerance = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_StatisticalTolerance
XCAFDimTolObjects_DimensionModif_ContinuousFeature = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_ContinuousFeature
XCAFDimTolObjects_DimensionModif_TwoPointSize = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_TwoPointSize
XCAFDimTolObjects_DimensionModif_LocalSizeDefinedBySphere = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_LocalSizeDefinedBySphere
XCAFDimTolObjects_DimensionModif_LeastSquaresAssociationCriterion = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_LeastSquaresAssociationCriterion
XCAFDimTolObjects_DimensionModif_MaximumInscribedAssociation = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_MaximumInscribedAssociation
XCAFDimTolObjects_DimensionModif_MinimumCircumscribedAssociation = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_MinimumCircumscribedAssociation
XCAFDimTolObjects_DimensionModif_CircumferenceDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_CircumferenceDiameter
XCAFDimTolObjects_DimensionModif_AreaDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_AreaDiameter
XCAFDimTolObjects_DimensionModif_VolumeDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_VolumeDiameter
XCAFDimTolObjects_DimensionModif_MaximumSize = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_MaximumSize
XCAFDimTolObjects_DimensionModif_MinimumSize = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_MinimumSize
XCAFDimTolObjects_DimensionModif_AverageSize = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_AverageSize
XCAFDimTolObjects_DimensionModif_MedianSize = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_MedianSize
XCAFDimTolObjects_DimensionModif_MidRangeSize = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_MidRangeSize
XCAFDimTolObjects_DimensionModif_RangeOfSizes = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_RangeOfSizes
XCAFDimTolObjects_DimensionModif_AnyRestrictedPortionOfFeature = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_AnyRestrictedPortionOfFeature
XCAFDimTolObjects_DimensionModif_AnyCrossSection = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_AnyCrossSection
XCAFDimTolObjects_DimensionModif_SpecificFixedCrossSection = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_SpecificFixedCrossSection
XCAFDimTolObjects_DimensionModif_CommonTolerance = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_CommonTolerance
XCAFDimTolObjects_DimensionModif_FreeStateCondition = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_FreeStateCondition
XCAFDimTolObjects_DimensionModif_Between = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModif_Between
XCAFDimTolObjects_DatumModifWithValue_None = _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifWithValue_None
XCAFDimTolObjects_DatumModifWithValue_CircularOrCylindrical = _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifWithValue_CircularOrCylindrical
XCAFDimTolObjects_DatumModifWithValue_Distance = _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifWithValue_Distance
XCAFDimTolObjects_DatumModifWithValue_Projected = _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifWithValue_Projected
XCAFDimTolObjects_DatumModifWithValue_Spherical = _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifWithValue_Spherical
XCAFDimTolObjects_DimensionFormVariance_None = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_None
XCAFDimTolObjects_DimensionFormVariance_A = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_A
XCAFDimTolObjects_DimensionFormVariance_B = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_B
XCAFDimTolObjects_DimensionFormVariance_C = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_C
XCAFDimTolObjects_DimensionFormVariance_CD = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_CD
XCAFDimTolObjects_DimensionFormVariance_D = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_D
XCAFDimTolObjects_DimensionFormVariance_E = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_E
XCAFDimTolObjects_DimensionFormVariance_EF = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_EF
XCAFDimTolObjects_DimensionFormVariance_F = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_F
XCAFDimTolObjects_DimensionFormVariance_FG = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_FG
XCAFDimTolObjects_DimensionFormVariance_G = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_G
XCAFDimTolObjects_DimensionFormVariance_H = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_H
XCAFDimTolObjects_DimensionFormVariance_JS = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_JS
XCAFDimTolObjects_DimensionFormVariance_J = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_J
XCAFDimTolObjects_DimensionFormVariance_K = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_K
XCAFDimTolObjects_DimensionFormVariance_M = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_M
XCAFDimTolObjects_DimensionFormVariance_N = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_N
XCAFDimTolObjects_DimensionFormVariance_P = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_P
XCAFDimTolObjects_DimensionFormVariance_R = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_R
XCAFDimTolObjects_DimensionFormVariance_S = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_S
XCAFDimTolObjects_DimensionFormVariance_T = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_T
XCAFDimTolObjects_DimensionFormVariance_U = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_U
XCAFDimTolObjects_DimensionFormVariance_V = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_V
XCAFDimTolObjects_DimensionFormVariance_X = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_X
XCAFDimTolObjects_DimensionFormVariance_Y = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_Y
XCAFDimTolObjects_DimensionFormVariance_Z = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_Z
XCAFDimTolObjects_DimensionFormVariance_ZA = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_ZA
XCAFDimTolObjects_DimensionFormVariance_ZB = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_ZB
XCAFDimTolObjects_DimensionFormVariance_ZC = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionFormVariance_ZC
XCAFDimTolObjects_GeomToleranceZoneModif_None = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceZoneModif_None
XCAFDimTolObjects_GeomToleranceZoneModif_Projected = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceZoneModif_Projected
XCAFDimTolObjects_GeomToleranceZoneModif_Runout = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceZoneModif_Runout
XCAFDimTolObjects_GeomToleranceZoneModif_NonUniform = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceZoneModif_NonUniform
XCAFDimTolObjects_DatumTargetType_Point = _XCAFDimTolObjects.XCAFDimTolObjects_DatumTargetType_Point
XCAFDimTolObjects_DatumTargetType_Line = _XCAFDimTolObjects.XCAFDimTolObjects_DatumTargetType_Line
XCAFDimTolObjects_DatumTargetType_Rectangle = _XCAFDimTolObjects.XCAFDimTolObjects_DatumTargetType_Rectangle
XCAFDimTolObjects_DatumTargetType_Circle = _XCAFDimTolObjects.XCAFDimTolObjects_DatumTargetType_Circle
XCAFDimTolObjects_DatumTargetType_Area = _XCAFDimTolObjects.XCAFDimTolObjects_DatumTargetType_Area
XCAFDimTolObjects_DatumSingleModif_AnyCrossSection = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_AnyCrossSection
XCAFDimTolObjects_DatumSingleModif_Any_LongitudinalSection = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Any_LongitudinalSection
XCAFDimTolObjects_DatumSingleModif_Basic = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Basic
XCAFDimTolObjects_DatumSingleModif_ContactingFeature = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_ContactingFeature
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintU = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintU
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintV = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintV
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintW = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintW
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintX = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintX
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintY = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintY
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintZ = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintZ
XCAFDimTolObjects_DatumSingleModif_DistanceVariable = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_DistanceVariable
XCAFDimTolObjects_DatumSingleModif_FreeState = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_FreeState
XCAFDimTolObjects_DatumSingleModif_LeastMaterialRequirement = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_LeastMaterialRequirement
XCAFDimTolObjects_DatumSingleModif_Line = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Line
XCAFDimTolObjects_DatumSingleModif_MajorDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_MajorDiameter
XCAFDimTolObjects_DatumSingleModif_MaximumMaterialRequirement = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_MaximumMaterialRequirement
XCAFDimTolObjects_DatumSingleModif_MinorDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_MinorDiameter
XCAFDimTolObjects_DatumSingleModif_Orientation = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Orientation
XCAFDimTolObjects_DatumSingleModif_PitchDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_PitchDiameter
XCAFDimTolObjects_DatumSingleModif_Plane = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Plane
XCAFDimTolObjects_DatumSingleModif_Point = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Point
XCAFDimTolObjects_DatumSingleModif_Translation = _XCAFDimTolObjects.XCAFDimTolObjects_DatumSingleModif_Translation
XCAFDimTolObjects_DimensionQualifier_None = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionQualifier_None
XCAFDimTolObjects_DimensionQualifier_Min = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionQualifier_Min
XCAFDimTolObjects_DimensionQualifier_Max = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionQualifier_Max
XCAFDimTolObjects_DimensionQualifier_Avg = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionQualifier_Avg
XCAFDimTolObjects_GeomToleranceTypeValue_None = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceTypeValue_None
XCAFDimTolObjects_GeomToleranceTypeValue_Diameter = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceTypeValue_Diameter
XCAFDimTolObjects_GeomToleranceTypeValue_SphericalDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceTypeValue_SphericalDiameter
XCAFDimTolObjects_ToleranceZoneAffectedPlane_None = _XCAFDimTolObjects.XCAFDimTolObjects_ToleranceZoneAffectedPlane_None
XCAFDimTolObjects_ToleranceZoneAffectedPlane_Intersection = _XCAFDimTolObjects.XCAFDimTolObjects_ToleranceZoneAffectedPlane_Intersection
XCAFDimTolObjects_ToleranceZoneAffectedPlane_Orientation = _XCAFDimTolObjects.XCAFDimTolObjects_ToleranceZoneAffectedPlane_Orientation
XCAFDimTolObjects_DimensionType_Location_None = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_None
XCAFDimTolObjects_DimensionType_Location_CurvedDistance = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_CurvedDistance
XCAFDimTolObjects_DimensionType_Location_LinearDistance = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToOuter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToOuter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToInner = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToInner
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToCenter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToCenter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToOuter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToOuter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToInner = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToInner
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToCenter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToCenter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToOuter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToOuter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToInner = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToInner
XCAFDimTolObjects_DimensionType_Location_Angular = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_Angular
XCAFDimTolObjects_DimensionType_Location_Oriented = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_Oriented
XCAFDimTolObjects_DimensionType_Location_WithPath = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Location_WithPath
XCAFDimTolObjects_DimensionType_Size_CurveLength = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_CurveLength
XCAFDimTolObjects_DimensionType_Size_Diameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_Diameter
XCAFDimTolObjects_DimensionType_Size_SphericalDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_SphericalDiameter
XCAFDimTolObjects_DimensionType_Size_Radius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_Radius
XCAFDimTolObjects_DimensionType_Size_SphericalRadius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_SphericalRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalMinorDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalMinorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalMajorDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalMajorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalMinorRadius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalMinorRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalMajorRadius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalMajorRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorDiameter = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorRadius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorRadius = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorRadius
XCAFDimTolObjects_DimensionType_Size_Thickness = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_Thickness
XCAFDimTolObjects_DimensionType_Size_Angular = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_Angular
XCAFDimTolObjects_DimensionType_Size_WithPath = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_Size_WithPath
XCAFDimTolObjects_DimensionType_CommonLabel = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_CommonLabel
XCAFDimTolObjects_DimensionType_DimensionPresentation = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionType_DimensionPresentation
XCAFDimTolObjects_GeomToleranceMatReqModif_None = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceMatReqModif_None
XCAFDimTolObjects_GeomToleranceMatReqModif_M = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceMatReqModif_M
XCAFDimTolObjects_GeomToleranceMatReqModif_L = _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceMatReqModif_L
XCAFDimTolObjects_DimensionGrade_IT01 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT01
XCAFDimTolObjects_DimensionGrade_IT0 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT0
XCAFDimTolObjects_DimensionGrade_IT1 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT1
XCAFDimTolObjects_DimensionGrade_IT2 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT2
XCAFDimTolObjects_DimensionGrade_IT3 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT3
XCAFDimTolObjects_DimensionGrade_IT4 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT4
XCAFDimTolObjects_DimensionGrade_IT5 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT5
XCAFDimTolObjects_DimensionGrade_IT6 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT6
XCAFDimTolObjects_DimensionGrade_IT7 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT7
XCAFDimTolObjects_DimensionGrade_IT8 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT8
XCAFDimTolObjects_DimensionGrade_IT9 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT9
XCAFDimTolObjects_DimensionGrade_IT10 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT10
XCAFDimTolObjects_DimensionGrade_IT11 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT11
XCAFDimTolObjects_DimensionGrade_IT12 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT12
XCAFDimTolObjects_DimensionGrade_IT13 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT13
XCAFDimTolObjects_DimensionGrade_IT14 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT14
XCAFDimTolObjects_DimensionGrade_IT15 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT15
XCAFDimTolObjects_DimensionGrade_IT16 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT16
XCAFDimTolObjects_DimensionGrade_IT17 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT17
XCAFDimTolObjects_DimensionGrade_IT18 = _XCAFDimTolObjects.XCAFDimTolObjects_DimensionGrade_IT18


class XCAFDimTolObjects_GeomToleranceType(IntEnum):
	XCAFDimTolObjects_GeomToleranceType_None = 0
	XCAFDimTolObjects_GeomToleranceType_Angularity = 1
	XCAFDimTolObjects_GeomToleranceType_CircularRunout = 2
	XCAFDimTolObjects_GeomToleranceType_CircularityOrRoundness = 3
	XCAFDimTolObjects_GeomToleranceType_Coaxiality = 4
	XCAFDimTolObjects_GeomToleranceType_Concentricity = 5
	XCAFDimTolObjects_GeomToleranceType_Cylindricity = 6
	XCAFDimTolObjects_GeomToleranceType_Flatness = 7
	XCAFDimTolObjects_GeomToleranceType_Parallelism = 8
	XCAFDimTolObjects_GeomToleranceType_Perpendicularity = 9
	XCAFDimTolObjects_GeomToleranceType_Position = 10
	XCAFDimTolObjects_GeomToleranceType_ProfileOfLine = 11
	XCAFDimTolObjects_GeomToleranceType_ProfileOfSurface = 12
	XCAFDimTolObjects_GeomToleranceType_Straightness = 13
	XCAFDimTolObjects_GeomToleranceType_Symmetry = 14
	XCAFDimTolObjects_GeomToleranceType_TotalRunout = 15
XCAFDimTolObjects_GeomToleranceType_None = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_None
XCAFDimTolObjects_GeomToleranceType_Angularity = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Angularity
XCAFDimTolObjects_GeomToleranceType_CircularRunout = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_CircularRunout
XCAFDimTolObjects_GeomToleranceType_CircularityOrRoundness = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_CircularityOrRoundness
XCAFDimTolObjects_GeomToleranceType_Coaxiality = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Coaxiality
XCAFDimTolObjects_GeomToleranceType_Concentricity = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Concentricity
XCAFDimTolObjects_GeomToleranceType_Cylindricity = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Cylindricity
XCAFDimTolObjects_GeomToleranceType_Flatness = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Flatness
XCAFDimTolObjects_GeomToleranceType_Parallelism = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Parallelism
XCAFDimTolObjects_GeomToleranceType_Perpendicularity = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Perpendicularity
XCAFDimTolObjects_GeomToleranceType_Position = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Position
XCAFDimTolObjects_GeomToleranceType_ProfileOfLine = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_ProfileOfLine
XCAFDimTolObjects_GeomToleranceType_ProfileOfSurface = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_ProfileOfSurface
XCAFDimTolObjects_GeomToleranceType_Straightness = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Straightness
XCAFDimTolObjects_GeomToleranceType_Symmetry = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_Symmetry
XCAFDimTolObjects_GeomToleranceType_TotalRunout = XCAFDimTolObjects_GeomToleranceType.XCAFDimTolObjects_GeomToleranceType_TotalRunout

class XCAFDimTolObjects_GeomToleranceModif(IntEnum):
	XCAFDimTolObjects_GeomToleranceModif_Any_Cross_Section = 0
	XCAFDimTolObjects_GeomToleranceModif_Common_Zone = 1
	XCAFDimTolObjects_GeomToleranceModif_Each_Radial_Element = 2
	XCAFDimTolObjects_GeomToleranceModif_Free_State = 3
	XCAFDimTolObjects_GeomToleranceModif_Least_Material_Requirement = 4
	XCAFDimTolObjects_GeomToleranceModif_Line_Element = 5
	XCAFDimTolObjects_GeomToleranceModif_Major_Diameter = 6
	XCAFDimTolObjects_GeomToleranceModif_Maximum_Material_Requirement = 7
	XCAFDimTolObjects_GeomToleranceModif_Minor_Diameter = 8
	XCAFDimTolObjects_GeomToleranceModif_Not_Convex = 9
	XCAFDimTolObjects_GeomToleranceModif_Pitch_Diameter = 10
	XCAFDimTolObjects_GeomToleranceModif_Reciprocity_Requirement = 11
	XCAFDimTolObjects_GeomToleranceModif_Separate_Requirement = 12
	XCAFDimTolObjects_GeomToleranceModif_Statistical_Tolerance = 13
	XCAFDimTolObjects_GeomToleranceModif_Tangent_Plane = 14
	XCAFDimTolObjects_GeomToleranceModif_All_Around = 15
	XCAFDimTolObjects_GeomToleranceModif_All_Over = 16
XCAFDimTolObjects_GeomToleranceModif_Any_Cross_Section = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Any_Cross_Section
XCAFDimTolObjects_GeomToleranceModif_Common_Zone = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Common_Zone
XCAFDimTolObjects_GeomToleranceModif_Each_Radial_Element = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Each_Radial_Element
XCAFDimTolObjects_GeomToleranceModif_Free_State = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Free_State
XCAFDimTolObjects_GeomToleranceModif_Least_Material_Requirement = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Least_Material_Requirement
XCAFDimTolObjects_GeomToleranceModif_Line_Element = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Line_Element
XCAFDimTolObjects_GeomToleranceModif_Major_Diameter = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Major_Diameter
XCAFDimTolObjects_GeomToleranceModif_Maximum_Material_Requirement = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Maximum_Material_Requirement
XCAFDimTolObjects_GeomToleranceModif_Minor_Diameter = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Minor_Diameter
XCAFDimTolObjects_GeomToleranceModif_Not_Convex = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Not_Convex
XCAFDimTolObjects_GeomToleranceModif_Pitch_Diameter = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Pitch_Diameter
XCAFDimTolObjects_GeomToleranceModif_Reciprocity_Requirement = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Reciprocity_Requirement
XCAFDimTolObjects_GeomToleranceModif_Separate_Requirement = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Separate_Requirement
XCAFDimTolObjects_GeomToleranceModif_Statistical_Tolerance = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Statistical_Tolerance
XCAFDimTolObjects_GeomToleranceModif_Tangent_Plane = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_Tangent_Plane
XCAFDimTolObjects_GeomToleranceModif_All_Around = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_All_Around
XCAFDimTolObjects_GeomToleranceModif_All_Over = XCAFDimTolObjects_GeomToleranceModif.XCAFDimTolObjects_GeomToleranceModif_All_Over

class XCAFDimTolObjects_DimensionModif(IntEnum):
	XCAFDimTolObjects_DimensionModif_ControlledRadius = 0
	XCAFDimTolObjects_DimensionModif_Square = 1
	XCAFDimTolObjects_DimensionModif_StatisticalTolerance = 2
	XCAFDimTolObjects_DimensionModif_ContinuousFeature = 3
	XCAFDimTolObjects_DimensionModif_TwoPointSize = 4
	XCAFDimTolObjects_DimensionModif_LocalSizeDefinedBySphere = 5
	XCAFDimTolObjects_DimensionModif_LeastSquaresAssociationCriterion = 6
	XCAFDimTolObjects_DimensionModif_MaximumInscribedAssociation = 7
	XCAFDimTolObjects_DimensionModif_MinimumCircumscribedAssociation = 8
	XCAFDimTolObjects_DimensionModif_CircumferenceDiameter = 9
	XCAFDimTolObjects_DimensionModif_AreaDiameter = 10
	XCAFDimTolObjects_DimensionModif_VolumeDiameter = 11
	XCAFDimTolObjects_DimensionModif_MaximumSize = 12
	XCAFDimTolObjects_DimensionModif_MinimumSize = 13
	XCAFDimTolObjects_DimensionModif_AverageSize = 14
	XCAFDimTolObjects_DimensionModif_MedianSize = 15
	XCAFDimTolObjects_DimensionModif_MidRangeSize = 16
	XCAFDimTolObjects_DimensionModif_RangeOfSizes = 17
	XCAFDimTolObjects_DimensionModif_AnyRestrictedPortionOfFeature = 18
	XCAFDimTolObjects_DimensionModif_AnyCrossSection = 19
	XCAFDimTolObjects_DimensionModif_SpecificFixedCrossSection = 20
	XCAFDimTolObjects_DimensionModif_CommonTolerance = 21
	XCAFDimTolObjects_DimensionModif_FreeStateCondition = 22
	XCAFDimTolObjects_DimensionModif_Between = 23
XCAFDimTolObjects_DimensionModif_ControlledRadius = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_ControlledRadius
XCAFDimTolObjects_DimensionModif_Square = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_Square
XCAFDimTolObjects_DimensionModif_StatisticalTolerance = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_StatisticalTolerance
XCAFDimTolObjects_DimensionModif_ContinuousFeature = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_ContinuousFeature
XCAFDimTolObjects_DimensionModif_TwoPointSize = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_TwoPointSize
XCAFDimTolObjects_DimensionModif_LocalSizeDefinedBySphere = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_LocalSizeDefinedBySphere
XCAFDimTolObjects_DimensionModif_LeastSquaresAssociationCriterion = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_LeastSquaresAssociationCriterion
XCAFDimTolObjects_DimensionModif_MaximumInscribedAssociation = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_MaximumInscribedAssociation
XCAFDimTolObjects_DimensionModif_MinimumCircumscribedAssociation = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_MinimumCircumscribedAssociation
XCAFDimTolObjects_DimensionModif_CircumferenceDiameter = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_CircumferenceDiameter
XCAFDimTolObjects_DimensionModif_AreaDiameter = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_AreaDiameter
XCAFDimTolObjects_DimensionModif_VolumeDiameter = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_VolumeDiameter
XCAFDimTolObjects_DimensionModif_MaximumSize = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_MaximumSize
XCAFDimTolObjects_DimensionModif_MinimumSize = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_MinimumSize
XCAFDimTolObjects_DimensionModif_AverageSize = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_AverageSize
XCAFDimTolObjects_DimensionModif_MedianSize = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_MedianSize
XCAFDimTolObjects_DimensionModif_MidRangeSize = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_MidRangeSize
XCAFDimTolObjects_DimensionModif_RangeOfSizes = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_RangeOfSizes
XCAFDimTolObjects_DimensionModif_AnyRestrictedPortionOfFeature = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_AnyRestrictedPortionOfFeature
XCAFDimTolObjects_DimensionModif_AnyCrossSection = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_AnyCrossSection
XCAFDimTolObjects_DimensionModif_SpecificFixedCrossSection = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_SpecificFixedCrossSection
XCAFDimTolObjects_DimensionModif_CommonTolerance = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_CommonTolerance
XCAFDimTolObjects_DimensionModif_FreeStateCondition = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_FreeStateCondition
XCAFDimTolObjects_DimensionModif_Between = XCAFDimTolObjects_DimensionModif.XCAFDimTolObjects_DimensionModif_Between

class XCAFDimTolObjects_DatumModifWithValue(IntEnum):
	XCAFDimTolObjects_DatumModifWithValue_None = 0
	XCAFDimTolObjects_DatumModifWithValue_CircularOrCylindrical = 1
	XCAFDimTolObjects_DatumModifWithValue_Distance = 2
	XCAFDimTolObjects_DatumModifWithValue_Projected = 3
	XCAFDimTolObjects_DatumModifWithValue_Spherical = 4
XCAFDimTolObjects_DatumModifWithValue_None = XCAFDimTolObjects_DatumModifWithValue.XCAFDimTolObjects_DatumModifWithValue_None
XCAFDimTolObjects_DatumModifWithValue_CircularOrCylindrical = XCAFDimTolObjects_DatumModifWithValue.XCAFDimTolObjects_DatumModifWithValue_CircularOrCylindrical
XCAFDimTolObjects_DatumModifWithValue_Distance = XCAFDimTolObjects_DatumModifWithValue.XCAFDimTolObjects_DatumModifWithValue_Distance
XCAFDimTolObjects_DatumModifWithValue_Projected = XCAFDimTolObjects_DatumModifWithValue.XCAFDimTolObjects_DatumModifWithValue_Projected
XCAFDimTolObjects_DatumModifWithValue_Spherical = XCAFDimTolObjects_DatumModifWithValue.XCAFDimTolObjects_DatumModifWithValue_Spherical

class XCAFDimTolObjects_DimensionFormVariance(IntEnum):
	XCAFDimTolObjects_DimensionFormVariance_None = 0
	XCAFDimTolObjects_DimensionFormVariance_A = 1
	XCAFDimTolObjects_DimensionFormVariance_B = 2
	XCAFDimTolObjects_DimensionFormVariance_C = 3
	XCAFDimTolObjects_DimensionFormVariance_CD = 4
	XCAFDimTolObjects_DimensionFormVariance_D = 5
	XCAFDimTolObjects_DimensionFormVariance_E = 6
	XCAFDimTolObjects_DimensionFormVariance_EF = 7
	XCAFDimTolObjects_DimensionFormVariance_F = 8
	XCAFDimTolObjects_DimensionFormVariance_FG = 9
	XCAFDimTolObjects_DimensionFormVariance_G = 10
	XCAFDimTolObjects_DimensionFormVariance_H = 11
	XCAFDimTolObjects_DimensionFormVariance_JS = 12
	XCAFDimTolObjects_DimensionFormVariance_J = 13
	XCAFDimTolObjects_DimensionFormVariance_K = 14
	XCAFDimTolObjects_DimensionFormVariance_M = 15
	XCAFDimTolObjects_DimensionFormVariance_N = 16
	XCAFDimTolObjects_DimensionFormVariance_P = 17
	XCAFDimTolObjects_DimensionFormVariance_R = 18
	XCAFDimTolObjects_DimensionFormVariance_S = 19
	XCAFDimTolObjects_DimensionFormVariance_T = 20
	XCAFDimTolObjects_DimensionFormVariance_U = 21
	XCAFDimTolObjects_DimensionFormVariance_V = 22
	XCAFDimTolObjects_DimensionFormVariance_X = 23
	XCAFDimTolObjects_DimensionFormVariance_Y = 24
	XCAFDimTolObjects_DimensionFormVariance_Z = 25
	XCAFDimTolObjects_DimensionFormVariance_ZA = 26
	XCAFDimTolObjects_DimensionFormVariance_ZB = 27
	XCAFDimTolObjects_DimensionFormVariance_ZC = 28
XCAFDimTolObjects_DimensionFormVariance_None = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_None
XCAFDimTolObjects_DimensionFormVariance_A = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_A
XCAFDimTolObjects_DimensionFormVariance_B = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_B
XCAFDimTolObjects_DimensionFormVariance_C = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_C
XCAFDimTolObjects_DimensionFormVariance_CD = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_CD
XCAFDimTolObjects_DimensionFormVariance_D = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_D
XCAFDimTolObjects_DimensionFormVariance_E = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_E
XCAFDimTolObjects_DimensionFormVariance_EF = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_EF
XCAFDimTolObjects_DimensionFormVariance_F = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_F
XCAFDimTolObjects_DimensionFormVariance_FG = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_FG
XCAFDimTolObjects_DimensionFormVariance_G = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_G
XCAFDimTolObjects_DimensionFormVariance_H = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_H
XCAFDimTolObjects_DimensionFormVariance_JS = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_JS
XCAFDimTolObjects_DimensionFormVariance_J = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_J
XCAFDimTolObjects_DimensionFormVariance_K = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_K
XCAFDimTolObjects_DimensionFormVariance_M = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_M
XCAFDimTolObjects_DimensionFormVariance_N = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_N
XCAFDimTolObjects_DimensionFormVariance_P = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_P
XCAFDimTolObjects_DimensionFormVariance_R = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_R
XCAFDimTolObjects_DimensionFormVariance_S = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_S
XCAFDimTolObjects_DimensionFormVariance_T = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_T
XCAFDimTolObjects_DimensionFormVariance_U = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_U
XCAFDimTolObjects_DimensionFormVariance_V = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_V
XCAFDimTolObjects_DimensionFormVariance_X = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_X
XCAFDimTolObjects_DimensionFormVariance_Y = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_Y
XCAFDimTolObjects_DimensionFormVariance_Z = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_Z
XCAFDimTolObjects_DimensionFormVariance_ZA = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_ZA
XCAFDimTolObjects_DimensionFormVariance_ZB = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_ZB
XCAFDimTolObjects_DimensionFormVariance_ZC = XCAFDimTolObjects_DimensionFormVariance.XCAFDimTolObjects_DimensionFormVariance_ZC

class XCAFDimTolObjects_GeomToleranceZoneModif(IntEnum):
	XCAFDimTolObjects_GeomToleranceZoneModif_None = 0
	XCAFDimTolObjects_GeomToleranceZoneModif_Projected = 1
	XCAFDimTolObjects_GeomToleranceZoneModif_Runout = 2
	XCAFDimTolObjects_GeomToleranceZoneModif_NonUniform = 3
XCAFDimTolObjects_GeomToleranceZoneModif_None = XCAFDimTolObjects_GeomToleranceZoneModif.XCAFDimTolObjects_GeomToleranceZoneModif_None
XCAFDimTolObjects_GeomToleranceZoneModif_Projected = XCAFDimTolObjects_GeomToleranceZoneModif.XCAFDimTolObjects_GeomToleranceZoneModif_Projected
XCAFDimTolObjects_GeomToleranceZoneModif_Runout = XCAFDimTolObjects_GeomToleranceZoneModif.XCAFDimTolObjects_GeomToleranceZoneModif_Runout
XCAFDimTolObjects_GeomToleranceZoneModif_NonUniform = XCAFDimTolObjects_GeomToleranceZoneModif.XCAFDimTolObjects_GeomToleranceZoneModif_NonUniform

class XCAFDimTolObjects_DatumTargetType(IntEnum):
	XCAFDimTolObjects_DatumTargetType_Point = 0
	XCAFDimTolObjects_DatumTargetType_Line = 1
	XCAFDimTolObjects_DatumTargetType_Rectangle = 2
	XCAFDimTolObjects_DatumTargetType_Circle = 3
	XCAFDimTolObjects_DatumTargetType_Area = 4
XCAFDimTolObjects_DatumTargetType_Point = XCAFDimTolObjects_DatumTargetType.XCAFDimTolObjects_DatumTargetType_Point
XCAFDimTolObjects_DatumTargetType_Line = XCAFDimTolObjects_DatumTargetType.XCAFDimTolObjects_DatumTargetType_Line
XCAFDimTolObjects_DatumTargetType_Rectangle = XCAFDimTolObjects_DatumTargetType.XCAFDimTolObjects_DatumTargetType_Rectangle
XCAFDimTolObjects_DatumTargetType_Circle = XCAFDimTolObjects_DatumTargetType.XCAFDimTolObjects_DatumTargetType_Circle
XCAFDimTolObjects_DatumTargetType_Area = XCAFDimTolObjects_DatumTargetType.XCAFDimTolObjects_DatumTargetType_Area

class XCAFDimTolObjects_DatumSingleModif(IntEnum):
	XCAFDimTolObjects_DatumSingleModif_AnyCrossSection = 0
	XCAFDimTolObjects_DatumSingleModif_Any_LongitudinalSection = 1
	XCAFDimTolObjects_DatumSingleModif_Basic = 2
	XCAFDimTolObjects_DatumSingleModif_ContactingFeature = 3
	XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintU = 4
	XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintV = 5
	XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintW = 6
	XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintX = 7
	XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintY = 8
	XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintZ = 9
	XCAFDimTolObjects_DatumSingleModif_DistanceVariable = 10
	XCAFDimTolObjects_DatumSingleModif_FreeState = 11
	XCAFDimTolObjects_DatumSingleModif_LeastMaterialRequirement = 12
	XCAFDimTolObjects_DatumSingleModif_Line = 13
	XCAFDimTolObjects_DatumSingleModif_MajorDiameter = 14
	XCAFDimTolObjects_DatumSingleModif_MaximumMaterialRequirement = 15
	XCAFDimTolObjects_DatumSingleModif_MinorDiameter = 16
	XCAFDimTolObjects_DatumSingleModif_Orientation = 17
	XCAFDimTolObjects_DatumSingleModif_PitchDiameter = 18
	XCAFDimTolObjects_DatumSingleModif_Plane = 19
	XCAFDimTolObjects_DatumSingleModif_Point = 20
	XCAFDimTolObjects_DatumSingleModif_Translation = 21
XCAFDimTolObjects_DatumSingleModif_AnyCrossSection = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_AnyCrossSection
XCAFDimTolObjects_DatumSingleModif_Any_LongitudinalSection = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Any_LongitudinalSection
XCAFDimTolObjects_DatumSingleModif_Basic = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Basic
XCAFDimTolObjects_DatumSingleModif_ContactingFeature = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_ContactingFeature
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintU = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintU
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintV = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintV
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintW = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintW
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintX = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintX
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintY = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintY
XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintZ = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DegreeOfFreedomConstraintZ
XCAFDimTolObjects_DatumSingleModif_DistanceVariable = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_DistanceVariable
XCAFDimTolObjects_DatumSingleModif_FreeState = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_FreeState
XCAFDimTolObjects_DatumSingleModif_LeastMaterialRequirement = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_LeastMaterialRequirement
XCAFDimTolObjects_DatumSingleModif_Line = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Line
XCAFDimTolObjects_DatumSingleModif_MajorDiameter = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_MajorDiameter
XCAFDimTolObjects_DatumSingleModif_MaximumMaterialRequirement = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_MaximumMaterialRequirement
XCAFDimTolObjects_DatumSingleModif_MinorDiameter = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_MinorDiameter
XCAFDimTolObjects_DatumSingleModif_Orientation = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Orientation
XCAFDimTolObjects_DatumSingleModif_PitchDiameter = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_PitchDiameter
XCAFDimTolObjects_DatumSingleModif_Plane = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Plane
XCAFDimTolObjects_DatumSingleModif_Point = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Point
XCAFDimTolObjects_DatumSingleModif_Translation = XCAFDimTolObjects_DatumSingleModif.XCAFDimTolObjects_DatumSingleModif_Translation

class XCAFDimTolObjects_DimensionQualifier(IntEnum):
	XCAFDimTolObjects_DimensionQualifier_None = 0
	XCAFDimTolObjects_DimensionQualifier_Min = 1
	XCAFDimTolObjects_DimensionQualifier_Max = 2
	XCAFDimTolObjects_DimensionQualifier_Avg = 3
XCAFDimTolObjects_DimensionQualifier_None = XCAFDimTolObjects_DimensionQualifier.XCAFDimTolObjects_DimensionQualifier_None
XCAFDimTolObjects_DimensionQualifier_Min = XCAFDimTolObjects_DimensionQualifier.XCAFDimTolObjects_DimensionQualifier_Min
XCAFDimTolObjects_DimensionQualifier_Max = XCAFDimTolObjects_DimensionQualifier.XCAFDimTolObjects_DimensionQualifier_Max
XCAFDimTolObjects_DimensionQualifier_Avg = XCAFDimTolObjects_DimensionQualifier.XCAFDimTolObjects_DimensionQualifier_Avg

class XCAFDimTolObjects_GeomToleranceTypeValue(IntEnum):
	XCAFDimTolObjects_GeomToleranceTypeValue_None = 0
	XCAFDimTolObjects_GeomToleranceTypeValue_Diameter = 1
	XCAFDimTolObjects_GeomToleranceTypeValue_SphericalDiameter = 2
XCAFDimTolObjects_GeomToleranceTypeValue_None = XCAFDimTolObjects_GeomToleranceTypeValue.XCAFDimTolObjects_GeomToleranceTypeValue_None
XCAFDimTolObjects_GeomToleranceTypeValue_Diameter = XCAFDimTolObjects_GeomToleranceTypeValue.XCAFDimTolObjects_GeomToleranceTypeValue_Diameter
XCAFDimTolObjects_GeomToleranceTypeValue_SphericalDiameter = XCAFDimTolObjects_GeomToleranceTypeValue.XCAFDimTolObjects_GeomToleranceTypeValue_SphericalDiameter

class XCAFDimTolObjects_ToleranceZoneAffectedPlane(IntEnum):
	XCAFDimTolObjects_ToleranceZoneAffectedPlane_None = 0
	XCAFDimTolObjects_ToleranceZoneAffectedPlane_Intersection = 1
	XCAFDimTolObjects_ToleranceZoneAffectedPlane_Orientation = 2
XCAFDimTolObjects_ToleranceZoneAffectedPlane_None = XCAFDimTolObjects_ToleranceZoneAffectedPlane.XCAFDimTolObjects_ToleranceZoneAffectedPlane_None
XCAFDimTolObjects_ToleranceZoneAffectedPlane_Intersection = XCAFDimTolObjects_ToleranceZoneAffectedPlane.XCAFDimTolObjects_ToleranceZoneAffectedPlane_Intersection
XCAFDimTolObjects_ToleranceZoneAffectedPlane_Orientation = XCAFDimTolObjects_ToleranceZoneAffectedPlane.XCAFDimTolObjects_ToleranceZoneAffectedPlane_Orientation

class XCAFDimTolObjects_DimensionType(IntEnum):
	XCAFDimTolObjects_DimensionType_Location_None = 0
	XCAFDimTolObjects_DimensionType_Location_CurvedDistance = 1
	XCAFDimTolObjects_DimensionType_Location_LinearDistance = 2
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToOuter = 3
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToInner = 4
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToCenter = 5
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToOuter = 6
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToInner = 7
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToCenter = 8
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToOuter = 9
	XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToInner = 10
	XCAFDimTolObjects_DimensionType_Location_Angular = 11
	XCAFDimTolObjects_DimensionType_Location_Oriented = 12
	XCAFDimTolObjects_DimensionType_Location_WithPath = 13
	XCAFDimTolObjects_DimensionType_Size_CurveLength = 14
	XCAFDimTolObjects_DimensionType_Size_Diameter = 15
	XCAFDimTolObjects_DimensionType_Size_SphericalDiameter = 16
	XCAFDimTolObjects_DimensionType_Size_Radius = 17
	XCAFDimTolObjects_DimensionType_Size_SphericalRadius = 18
	XCAFDimTolObjects_DimensionType_Size_ToroidalMinorDiameter = 19
	XCAFDimTolObjects_DimensionType_Size_ToroidalMajorDiameter = 20
	XCAFDimTolObjects_DimensionType_Size_ToroidalMinorRadius = 21
	XCAFDimTolObjects_DimensionType_Size_ToroidalMajorRadius = 22
	XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorDiameter = 23
	XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorDiameter = 24
	XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorRadius = 25
	XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorRadius = 26
	XCAFDimTolObjects_DimensionType_Size_Thickness = 27
	XCAFDimTolObjects_DimensionType_Size_Angular = 28
	XCAFDimTolObjects_DimensionType_Size_WithPath = 29
	XCAFDimTolObjects_DimensionType_CommonLabel = 30
	XCAFDimTolObjects_DimensionType_DimensionPresentation = 31
XCAFDimTolObjects_DimensionType_Location_None = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_None
XCAFDimTolObjects_DimensionType_Location_CurvedDistance = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_CurvedDistance
XCAFDimTolObjects_DimensionType_Location_LinearDistance = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToOuter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToOuter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToInner = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromCenterToInner
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToCenter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToCenter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToOuter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToOuter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToInner = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromOuterToInner
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToCenter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToCenter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToOuter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToOuter
XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToInner = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_LinearDistance_FromInnerToInner
XCAFDimTolObjects_DimensionType_Location_Angular = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_Angular
XCAFDimTolObjects_DimensionType_Location_Oriented = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_Oriented
XCAFDimTolObjects_DimensionType_Location_WithPath = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Location_WithPath
XCAFDimTolObjects_DimensionType_Size_CurveLength = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_CurveLength
XCAFDimTolObjects_DimensionType_Size_Diameter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_Diameter
XCAFDimTolObjects_DimensionType_Size_SphericalDiameter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_SphericalDiameter
XCAFDimTolObjects_DimensionType_Size_Radius = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_Radius
XCAFDimTolObjects_DimensionType_Size_SphericalRadius = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_SphericalRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalMinorDiameter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalMinorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalMajorDiameter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalMajorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalMinorRadius = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalMinorRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalMajorRadius = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalMajorRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorDiameter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorDiameter = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorDiameter
XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorRadius = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalHighMajorRadius
XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorRadius = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_ToroidalLowMajorRadius
XCAFDimTolObjects_DimensionType_Size_Thickness = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_Thickness
XCAFDimTolObjects_DimensionType_Size_Angular = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_Angular
XCAFDimTolObjects_DimensionType_Size_WithPath = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_Size_WithPath
XCAFDimTolObjects_DimensionType_CommonLabel = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_CommonLabel
XCAFDimTolObjects_DimensionType_DimensionPresentation = XCAFDimTolObjects_DimensionType.XCAFDimTolObjects_DimensionType_DimensionPresentation

class XCAFDimTolObjects_GeomToleranceMatReqModif(IntEnum):
	XCAFDimTolObjects_GeomToleranceMatReqModif_None = 0
	XCAFDimTolObjects_GeomToleranceMatReqModif_M = 1
	XCAFDimTolObjects_GeomToleranceMatReqModif_L = 2
XCAFDimTolObjects_GeomToleranceMatReqModif_None = XCAFDimTolObjects_GeomToleranceMatReqModif.XCAFDimTolObjects_GeomToleranceMatReqModif_None
XCAFDimTolObjects_GeomToleranceMatReqModif_M = XCAFDimTolObjects_GeomToleranceMatReqModif.XCAFDimTolObjects_GeomToleranceMatReqModif_M
XCAFDimTolObjects_GeomToleranceMatReqModif_L = XCAFDimTolObjects_GeomToleranceMatReqModif.XCAFDimTolObjects_GeomToleranceMatReqModif_L

class XCAFDimTolObjects_DimensionGrade(IntEnum):
	XCAFDimTolObjects_DimensionGrade_IT01 = 0
	XCAFDimTolObjects_DimensionGrade_IT0 = 1
	XCAFDimTolObjects_DimensionGrade_IT1 = 2
	XCAFDimTolObjects_DimensionGrade_IT2 = 3
	XCAFDimTolObjects_DimensionGrade_IT3 = 4
	XCAFDimTolObjects_DimensionGrade_IT4 = 5
	XCAFDimTolObjects_DimensionGrade_IT5 = 6
	XCAFDimTolObjects_DimensionGrade_IT6 = 7
	XCAFDimTolObjects_DimensionGrade_IT7 = 8
	XCAFDimTolObjects_DimensionGrade_IT8 = 9
	XCAFDimTolObjects_DimensionGrade_IT9 = 10
	XCAFDimTolObjects_DimensionGrade_IT10 = 11
	XCAFDimTolObjects_DimensionGrade_IT11 = 12
	XCAFDimTolObjects_DimensionGrade_IT12 = 13
	XCAFDimTolObjects_DimensionGrade_IT13 = 14
	XCAFDimTolObjects_DimensionGrade_IT14 = 15
	XCAFDimTolObjects_DimensionGrade_IT15 = 16
	XCAFDimTolObjects_DimensionGrade_IT16 = 17
	XCAFDimTolObjects_DimensionGrade_IT17 = 18
	XCAFDimTolObjects_DimensionGrade_IT18 = 19
XCAFDimTolObjects_DimensionGrade_IT01 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT01
XCAFDimTolObjects_DimensionGrade_IT0 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT0
XCAFDimTolObjects_DimensionGrade_IT1 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT1
XCAFDimTolObjects_DimensionGrade_IT2 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT2
XCAFDimTolObjects_DimensionGrade_IT3 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT3
XCAFDimTolObjects_DimensionGrade_IT4 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT4
XCAFDimTolObjects_DimensionGrade_IT5 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT5
XCAFDimTolObjects_DimensionGrade_IT6 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT6
XCAFDimTolObjects_DimensionGrade_IT7 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT7
XCAFDimTolObjects_DimensionGrade_IT8 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT8
XCAFDimTolObjects_DimensionGrade_IT9 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT9
XCAFDimTolObjects_DimensionGrade_IT10 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT10
XCAFDimTolObjects_DimensionGrade_IT11 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT11
XCAFDimTolObjects_DimensionGrade_IT12 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT12
XCAFDimTolObjects_DimensionGrade_IT13 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT13
XCAFDimTolObjects_DimensionGrade_IT14 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT14
XCAFDimTolObjects_DimensionGrade_IT15 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT15
XCAFDimTolObjects_DimensionGrade_IT16 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT16
XCAFDimTolObjects_DimensionGrade_IT17 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT17
XCAFDimTolObjects_DimensionGrade_IT18 = XCAFDimTolObjects_DimensionGrade.XCAFDimTolObjects_DimensionGrade_IT18


def Handle_XCAFDimTolObjects_DatumObject_Create() -> "opencascade::handle< XCAFDimTolObjects_DatumObject >":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_DatumObject_Create()

def Handle_XCAFDimTolObjects_DatumObject_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XCAFDimTolObjects_DatumObject >":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_DatumObject_DownCast(t)

def Handle_XCAFDimTolObjects_DatumObject_IsNull(t: "opencascade::handle< XCAFDimTolObjects_DatumObject > const &") -> "bool":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_DatumObject_IsNull(t)

def Handle_XCAFDimTolObjects_DimensionObject_Create() -> "opencascade::handle< XCAFDimTolObjects_DimensionObject >":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_DimensionObject_Create()

def Handle_XCAFDimTolObjects_DimensionObject_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XCAFDimTolObjects_DimensionObject >":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_DimensionObject_DownCast(t)

def Handle_XCAFDimTolObjects_DimensionObject_IsNull(t: "opencascade::handle< XCAFDimTolObjects_DimensionObject > const &") -> "bool":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_DimensionObject_IsNull(t)

def Handle_XCAFDimTolObjects_GeomToleranceObject_Create() -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_GeomToleranceObject_Create()

def Handle_XCAFDimTolObjects_GeomToleranceObject_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_GeomToleranceObject_DownCast(t)

def Handle_XCAFDimTolObjects_GeomToleranceObject_IsNull(t: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "bool":
    return _XCAFDimTolObjects.Handle_XCAFDimTolObjects_GeomToleranceObject_IsNull(t)
class XCAFDimTolObjects_DataMapOfToleranceDatum(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >,opencascade::handle< XCAFDimTolObjects_DatumObject >,NCollection_DefaultHasher< opencascade::handle< Standard_Transient > > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_begin(self)

    def end(self) -> "NCollection_DataMap< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >,opencascade::handle< XCAFDimTolObjects_DatumObject >,NCollection_DefaultHasher< opencascade::handle< Standard_Transient > > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_end(self)

    def cbegin(self) -> "NCollection_DataMap< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >,opencascade::handle< XCAFDimTolObjects_DatumObject >,NCollection_DefaultHasher< opencascade::handle< Standard_Transient > > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_cbegin(self)

    def cend(self) -> "NCollection_DataMap< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >,opencascade::handle< XCAFDimTolObjects_DatumObject >,NCollection_DefaultHasher< opencascade::handle< Standard_Transient > > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DataMapOfToleranceDatum(*args))

    def Exchange(self, theOther: "XCAFDimTolObjects_DataMapOfToleranceDatum") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Exchange(self, theOther)

    def Assign(self, theOther: "XCAFDimTolObjects_DataMapOfToleranceDatum") -> "NCollection_DataMap< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >,opencascade::handle< XCAFDimTolObjects_DatumObject >,TColStd_MapTransientHasher > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_DataMapOfToleranceDatum") -> "NCollection_DataMap< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject >,opencascade::handle< XCAFDimTolObjects_DatumObject >,TColStd_MapTransientHasher > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_ReSize(self, N)

    def Bind(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &", theItem: "opencascade::handle< XCAFDimTolObjects_DatumObject > const &") -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Bind(self, theKey, theItem)

    def Bound(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &", theItem: "opencascade::handle< XCAFDimTolObjects_DatumObject > const &") -> "opencascade::handle< XCAFDimTolObjects_DatumObject > *":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_IsBound(self, theKey)

    def UnBind(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_UnBind(self, theKey)

    def Seek(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "opencascade::handle< XCAFDimTolObjects_DatumObject > const *":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Find(self, *args)

    def ChangeSeek(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "opencascade::handle< XCAFDimTolObjects_DatumObject > *":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "opencascade::handle< XCAFDimTolObjects_DatumObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_ChangeFind(self, theKey)

    def __call__(self, *args) -> "opencascade::handle< XCAFDimTolObjects_DatumObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Clear(self, *args)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DataMapOfToleranceDatum

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_Size(self)

# Register XCAFDimTolObjects_DataMapOfToleranceDatum in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DataMapOfToleranceDatum_swigregister(XCAFDimTolObjects_DataMapOfToleranceDatum)

class XCAFDimTolObjects_DatumModifiersSequence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DatumSingleModif >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_begin(self)

    def end(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DatumSingleModif >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_end(self)

    def cbegin(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DatumSingleModif >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_cbegin(self)

    def cend(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DatumSingleModif >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DatumModifiersSequence(*args))

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Clear(self, theAllocator)

    def Assign(self, theOther: "XCAFDimTolObjects_DatumModifiersSequence") -> "NCollection_Sequence< XCAFDimTolObjects_DatumSingleModif > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_DatumModifiersSequence") -> "NCollection_Sequence< XCAFDimTolObjects_DatumSingleModif > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XCAFDimTolObjects_DatumModifiersSequence") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Split(self, theIndex, theSeq)

    def First(self) -> "XCAFDimTolObjects_DatumSingleModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_First(self)

    def ChangeFirst(self) -> "XCAFDimTolObjects_DatumSingleModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_ChangeFirst(self)

    def Last(self) -> "XCAFDimTolObjects_DatumSingleModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Last(self)

    def ChangeLast(self) -> "XCAFDimTolObjects_DatumSingleModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "XCAFDimTolObjects_DatumSingleModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "XCAFDimTolObjects_DatumSingleModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "XCAFDimTolObjects_DatumSingleModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "XCAFDimTolObjects_DatumSingleModif const &") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DatumModifiersSequence

    def __len__(self):
        return self.Size()


# Register XCAFDimTolObjects_DatumModifiersSequence in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_swigregister(XCAFDimTolObjects_DatumModifiersSequence)

def XCAFDimTolObjects_DatumModifiersSequence_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XCAFDimTolObjects.XCAFDimTolObjects_DatumModifiersSequence_delNode(theNode, theAl)

class XCAFDimTolObjects_DatumObjectSequence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DatumObject > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DatumObject > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DatumObject > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DatumObject > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DatumObjectSequence(*args))

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Clear(self, theAllocator)

    def Assign(self, theOther: "XCAFDimTolObjects_DatumObjectSequence") -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DatumObject > > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_DatumObjectSequence") -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DatumObject > > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XCAFDimTolObjects_DatumObjectSequence") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< XCAFDimTolObjects_DatumObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_First(self)

    def ChangeFirst(self) -> "opencascade::handle< XCAFDimTolObjects_DatumObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< XCAFDimTolObjects_DatumObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Last(self)

    def ChangeLast(self) -> "opencascade::handle< XCAFDimTolObjects_DatumObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< XCAFDimTolObjects_DatumObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< XCAFDimTolObjects_DatumObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< XCAFDimTolObjects_DatumObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< XCAFDimTolObjects_DatumObject > const &") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DatumObjectSequence

    def __len__(self):
        return self.Size()


# Register XCAFDimTolObjects_DatumObjectSequence in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_swigregister(XCAFDimTolObjects_DatumObjectSequence)

def XCAFDimTolObjects_DatumObjectSequence_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObjectSequence_delNode(theNode, theAl)

class XCAFDimTolObjects_DimensionModifiersSequence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DimensionModif >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_begin(self)

    def end(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DimensionModif >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_end(self)

    def cbegin(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DimensionModif >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_cbegin(self)

    def cend(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_DimensionModif >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DimensionModifiersSequence(*args))

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Clear(self, theAllocator)

    def Assign(self, theOther: "XCAFDimTolObjects_DimensionModifiersSequence") -> "NCollection_Sequence< XCAFDimTolObjects_DimensionModif > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_DimensionModifiersSequence") -> "NCollection_Sequence< XCAFDimTolObjects_DimensionModif > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XCAFDimTolObjects_DimensionModifiersSequence") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Split(self, theIndex, theSeq)

    def First(self) -> "XCAFDimTolObjects_DimensionModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_First(self)

    def ChangeFirst(self) -> "XCAFDimTolObjects_DimensionModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_ChangeFirst(self)

    def Last(self) -> "XCAFDimTolObjects_DimensionModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Last(self)

    def ChangeLast(self) -> "XCAFDimTolObjects_DimensionModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "XCAFDimTolObjects_DimensionModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "XCAFDimTolObjects_DimensionModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "XCAFDimTolObjects_DimensionModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "XCAFDimTolObjects_DimensionModif const &") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DimensionModifiersSequence

    def __len__(self):
        return self.Size()


# Register XCAFDimTolObjects_DimensionModifiersSequence in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_swigregister(XCAFDimTolObjects_DimensionModifiersSequence)

def XCAFDimTolObjects_DimensionModifiersSequence_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionModifiersSequence_delNode(theNode, theAl)

class XCAFDimTolObjects_DimensionObjectSequence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DimensionObject > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DimensionObject > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DimensionObject > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DimensionObject > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DimensionObjectSequence(*args))

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Clear(self, theAllocator)

    def Assign(self, theOther: "XCAFDimTolObjects_DimensionObjectSequence") -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DimensionObject > > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_DimensionObjectSequence") -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_DimensionObject > > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XCAFDimTolObjects_DimensionObjectSequence") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_First(self)

    def ChangeFirst(self) -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Last(self)

    def ChangeLast(self) -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< XCAFDimTolObjects_DimensionObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< XCAFDimTolObjects_DimensionObject > const &") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DimensionObjectSequence

    def __len__(self):
        return self.Size()


# Register XCAFDimTolObjects_DimensionObjectSequence in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_swigregister(XCAFDimTolObjects_DimensionObjectSequence)

def XCAFDimTolObjects_DimensionObjectSequence_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObjectSequence_delNode(theNode, theAl)

class XCAFDimTolObjects_GeomToleranceModifiersSequence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_GeomToleranceModif >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_begin(self)

    def end(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_GeomToleranceModif >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_end(self)

    def cbegin(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_GeomToleranceModif >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_cbegin(self)

    def cend(self) -> "NCollection_Sequence< enum XCAFDimTolObjects_GeomToleranceModif >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_GeomToleranceModifiersSequence(*args))

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Clear(self, theAllocator)

    def Assign(self, theOther: "XCAFDimTolObjects_GeomToleranceModifiersSequence") -> "NCollection_Sequence< XCAFDimTolObjects_GeomToleranceModif > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_GeomToleranceModifiersSequence") -> "NCollection_Sequence< XCAFDimTolObjects_GeomToleranceModif > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XCAFDimTolObjects_GeomToleranceModifiersSequence") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Split(self, theIndex, theSeq)

    def First(self) -> "XCAFDimTolObjects_GeomToleranceModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_First(self)

    def ChangeFirst(self) -> "XCAFDimTolObjects_GeomToleranceModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_ChangeFirst(self)

    def Last(self) -> "XCAFDimTolObjects_GeomToleranceModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Last(self)

    def ChangeLast(self) -> "XCAFDimTolObjects_GeomToleranceModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "XCAFDimTolObjects_GeomToleranceModif const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "XCAFDimTolObjects_GeomToleranceModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "XCAFDimTolObjects_GeomToleranceModif &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "XCAFDimTolObjects_GeomToleranceModif const &") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_GeomToleranceModifiersSequence

    def __len__(self):
        return self.Size()


# Register XCAFDimTolObjects_GeomToleranceModifiersSequence in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_swigregister(XCAFDimTolObjects_GeomToleranceModifiersSequence)

def XCAFDimTolObjects_GeomToleranceModifiersSequence_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceModifiersSequence_delNode(theNode, theAl)

class XCAFDimTolObjects_GeomToleranceObjectSequence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > >::iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > >::const_iterator":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_cend(self)

    def __init__(self, *args):
        _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_GeomToleranceObjectSequence(*args))

    def Size(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Size(self)

    def Length(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_IsEmpty(self)

    def Reverse(self) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_delNode(theNode, theAl)

    def Clear(self, theAllocator: "TDF_HAllocator"=0) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Clear(self, theAllocator)

    def Assign(self, theOther: "XCAFDimTolObjects_GeomToleranceObjectSequence") -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Assign(self, theOther)

    def Set(self, theOther: "XCAFDimTolObjects_GeomToleranceObjectSequence") -> "NCollection_Sequence< opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "XCAFDimTolObjects_GeomToleranceObjectSequence") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_First(self)

    def ChangeFirst(self) -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Last(self)

    def ChangeLast(self) -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > &":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< XCAFDimTolObjects_GeomToleranceObject > const &") -> "void":
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_GeomToleranceObjectSequence

    def __len__(self):
        return self.Size()


# Register XCAFDimTolObjects_GeomToleranceObjectSequence in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_swigregister(XCAFDimTolObjects_GeomToleranceObjectSequence)

def XCAFDimTolObjects_GeomToleranceObjectSequence_delNode(theNode: "NCollection_SeqNode *", theAl: "TDF_HAllocator") -> "void":
    return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObjectSequence_delNode(theNode, theAl)

class XCAFDimTolObjects_DatumObject(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        theObj: XCAFDimTolObjects_DatumObject

        Returns
        -------
        None

        """
        _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DatumObject(*args))

    def AddModifier(self, *args) -> "void":
        r"""
        Adds a modifier to the datum sequence of modifiers.

        Parameters
        ----------
        theModifier: XCAFDimTolObjects_DatumSingleModif

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_AddModifier(self, *args)

    def GetDatumTarget(self, *args) -> "TopoDS_Shape":
        r"""
        Returns datum target shape.

        Returns
        -------
        TopoDS_Shape

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetDatumTarget(self, *args)

    def GetDatumTargetAxis(self, *args) -> "gp_Ax2":
        r"""
        Returns datum target axis. the z axis of the datum placement denotes the normal of the surface pointing away from the material. .

        Returns
        -------
        gp_Ax2

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetDatumTargetAxis(self, *args)

    def GetDatumTargetLength(self, *args) -> "Standard_Real":
        r"""
        Returns datum target length for line and rectangle types. the length along the x axis of the datum placement.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetDatumTargetLength(self, *args)

    def GetDatumTargetNumber(self, *args) -> "Standard_Integer":
        r"""
        Returns datum target number.

        Returns
        -------
        int

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetDatumTargetNumber(self, *args)

    def GetDatumTargetType(self, *args) -> "XCAFDimTolObjects_DatumTargetType":
        r"""
        Returns datum target type.

        Returns
        -------
        XCAFDimTolObjects_DatumTargetType

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetDatumTargetType(self, *args)

    def GetDatumTargetWidth(self, *args) -> "Standard_Real":
        r"""
        Returns datum target width for rectangle type. the width along the derived y axis, with the placement itself positioned at the centre of the rectangle.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetDatumTargetWidth(self, *args)

    def GetModifierWithValue(self, *args) -> "void":
        r"""
        Retrieves datum modifier with value.

        Parameters
        ----------
        theModifier: XCAFDimTolObjects_DatumModifWithValue

        Returns
        -------
        theValue: float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetModifierWithValue(self, *args)

    def GetModifiers(self, *args) -> "XCAFDimTolObjects_DatumModifiersSequence":
        r"""
        Returns a sequence of modifiers of the datum.

        Returns
        -------
        XCAFDimTolObjects_DatumModifiersSequence

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetModifiers(self, *args)

    def GetName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns datum name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetName(self, *args)

    def GetPlane(self, *args) -> "gp_Ax2 const":
        r"""
        Returns annotation plane.

        Returns
        -------
        gp_Ax2

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetPlane(self, *args)

    def GetPoint(self, *args) -> "gp_Pnt const":
        r"""
        Gets point on the datum shape.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetPoint(self, *args)

    def GetPointTextAttach(self, *args) -> "gp_Pnt const":
        r"""
        Gets datum text position.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetPointTextAttach(self, *args)

    def GetPosition(self, *args) -> "Standard_Integer":
        r"""
        Returns datum position in the related geometric tolerance object.

        Returns
        -------
        int

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetPosition(self, *args)

    def GetPresentation(self, *args) -> "TopoDS_Shape":
        r"""
        Returns graphical presentation of the object.

        Returns
        -------
        TopoDS_Shape

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetPresentation(self, *args)

    def GetPresentationName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns graphical presentation of the object.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetPresentationName(self, *args)

    def GetSemanticName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns semantic name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_GetSemanticName(self, *args)

    def HasDatumTargetParams(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the datum has valid parameters for datum target (width, length, circle radius etc).

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_HasDatumTargetParams(self, *args)

    def HasPlane(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the datum has annotation plane.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_HasPlane(self, *args)

    def HasPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if point on the datum target is specified.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_HasPoint(self, *args)

    def HasPointText(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the datum text position is specified.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_HasPointText(self, *args)

    def IsDatumTarget(self, *args) -> "void":
        r"""
        Returns true if the datum target is specified.

        Returns
        -------
        bool
        Sets or drops the datum target indicator.

        Parameters
        ----------
        theIsDT: bool

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_IsDatumTarget(self, *args)

    def SetDatumTarget(self, *args) -> "void":
        r"""
        Sets datum target shape.

        Parameters
        ----------
        theShape: TopoDS_Shape

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetDatumTarget(self, *args)

    def SetDatumTargetAxis(self, *args) -> "void":
        r"""
        Sets datum target axis.

        Parameters
        ----------
        theAxis: gp_Ax2

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetDatumTargetAxis(self, *args)

    def SetDatumTargetLength(self, *args) -> "void":
        r"""
        Sets datum target length.

        Parameters
        ----------
        theLength: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetDatumTargetLength(self, *args)

    def SetDatumTargetNumber(self, *args) -> "void":
        r"""
        Sets datum target number.

        Parameters
        ----------
        theNumber: int

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetDatumTargetNumber(self, *args)

    def SetDatumTargetType(self, *args) -> "void":
        r"""
        Sets datum target to point, line, rectangle, circle or area type.

        Parameters
        ----------
        theType: XCAFDimTolObjects_DatumTargetType

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetDatumTargetType(self, *args)

    def SetDatumTargetWidth(self, *args) -> "void":
        r"""
        Sets datum target width.

        Parameters
        ----------
        theWidth: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetDatumTargetWidth(self, *args)

    def SetModifierWithValue(self, *args) -> "void":
        r"""
        Sets datum modifier with value.

        Parameters
        ----------
        theModifier: XCAFDimTolObjects_DatumModifWithValue
        theValue: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetModifierWithValue(self, *args)

    def SetModifiers(self, *args) -> "void":
        r"""
        Sets new sequence of datum modifiers.

        Parameters
        ----------
        theModifiers: XCAFDimTolObjects_DatumModifiersSequence

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetModifiers(self, *args)

    def SetName(self, *args) -> "void":
        r"""
        Sets datum name.

        Parameters
        ----------
        theTag: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetName(self, *args)

    def SetPlane(self, *args) -> "void":
        r"""
        Sets annotation plane.

        Parameters
        ----------
        thePlane: gp_Ax2

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetPlane(self, *args)

    def SetPoint(self, *args) -> "void":
        r"""
        Sets a point on the datum target shape.

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetPoint(self, *args)

    def SetPointTextAttach(self, *args) -> "void":
        r"""
        Sets a position of the datum text.

        Parameters
        ----------
        thePntText: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetPointTextAttach(self, *args)

    def SetPosition(self, *args) -> "void":
        r"""
        Sets datum position in the related geometric tolerance object.

        Parameters
        ----------
        thePosition: int

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetPosition(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        Set graphical presentation for object.

        Parameters
        ----------
        thePresentation: TopoDS_Shape
        thePresentationName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetPresentation(self, *args)

    def SetSemanticName(self, *args) -> "void":
        r"""
        Sets semantic name.

        Parameters
        ----------
        theName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_SetSemanticName(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XCAFDimTolObjects_DatumObject_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DatumObject

# Register XCAFDimTolObjects_DatumObject in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DatumObject_swigregister(XCAFDimTolObjects_DatumObject)

class XCAFDimTolObjects_DimensionObject(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        theObj: XCAFDimTolObjects_DimensionObject

        Returns
        -------
        None

        """
        _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_DimensionObject(*args))

    def AddDescription(self, *args) -> "void":
        r"""
        Add new description.

        Parameters
        ----------
        theDescription: TCollection_HAsciiString
        theName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_AddDescription(self, *args)

    def AddModifier(self, *args) -> "void":
        r"""
        Adds a modifier to the dimension sequence of modifiers.

        Parameters
        ----------
        theModifier: XCAFDimTolObjects_DimensionModif

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_AddModifier(self, *args)

    def GetClassOfTolerance(self, *args) -> "Standard_Boolean":
        r"""
        Retrieves tolerance class parameters of the dimension. returns true if the dimension is toleranced.

        Parameters
        ----------
        theFormVariance: XCAFDimTolObjects_DimensionFormVariance
        theGrade: XCAFDimTolObjects_DimensionGrade

        Returns
        -------
        theHole: bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetClassOfTolerance(self, *args)

    def GetDescription(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns description with the given number.

        Parameters
        ----------
        theNumber: int

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetDescription(self, *args)

    def GetDescriptionName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns name of description with the given number.

        Parameters
        ----------
        theNumber: int

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetDescriptionName(self, *args)

    def GetDirection(self, *args) -> "Standard_Boolean":
        r"""
        Returns the orientation of the dimension in annotation plane.

        Parameters
        ----------
        theDir: gp_Dir

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetDirection(self, *args)

    def GetLowerBound(self, *args) -> "Standard_Real":
        r"""
        Returns the lower bound of the range dimension, otherwise - zero.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetLowerBound(self, *args)

    def GetLowerTolValue(self, *args) -> "Standard_Real":
        r"""
        Returns the upper value of the toleranced dimension, otherwise - zero.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetLowerTolValue(self, *args)

    def GetModifiers(self, *args) -> "XCAFDimTolObjects_DimensionModifiersSequence":
        r"""
        Returns a sequence of modifiers of the dimension.

        Returns
        -------
        XCAFDimTolObjects_DimensionModifiersSequence

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetModifiers(self, *args)

    def GetNbOfDecimalPlaces(self, *args) -> "void":
        r"""
        Returns the number of places to the left and right of the decimal point respectively.

        Parameters
        ----------

        Returns
        -------
        theL: int
        theR: int

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetNbOfDecimalPlaces(self, *args)

    def GetPath(self, *args) -> "TopoDS_Edge":
        r"""
        Returns a 'curve' along which the dimension is measured.

        Returns
        -------
        TopoDS_Edge

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPath(self, *args)

    def GetPlane(self, *args) -> "gp_Ax2 const":
        r"""
        Returns annotation plane.

        Returns
        -------
        gp_Ax2

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPlane(self, *args)

    def GetPoint(self, *args) -> "gp_Pnt":
        r"""
        Get connection point (for dimesional_size), get connection point for the first shape (for dimensional_location).

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPoint(self, *args)

    def GetPoint2(self, *args) -> "gp_Pnt":
        r"""
        No available documentation.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPoint2(self, *args)

    def GetPointTextAttach(self, *args) -> "gp_Pnt const":
        r"""
        Returns position of the dimension text.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPointTextAttach(self, *args)

    def GetPresentation(self, *args) -> "TopoDS_Shape":
        r"""
        Returns graphical presentation of the object.

        Returns
        -------
        TopoDS_Shape

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPresentation(self, *args)

    def GetPresentationName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns graphical presentation of the object.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetPresentationName(self, *args)

    def GetQualifier(self, *args) -> "XCAFDimTolObjects_DimensionQualifier":
        r"""
        Returns dimension qualifier.

        Returns
        -------
        XCAFDimTolObjects_DimensionQualifier

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetQualifier(self, *args)

    def GetSemanticName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns semantic name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetSemanticName(self, *args)

    def GetType(self, *args) -> "XCAFDimTolObjects_DimensionType":
        r"""
        Returns dimension type.

        Returns
        -------
        XCAFDimTolObjects_DimensionType

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetType(self, *args)

    def GetUpperBound(self, *args) -> "Standard_Real":
        r"""
        Returns the upper bound of the range dimension, otherwise - zero.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetUpperBound(self, *args)

    def GetUpperTolValue(self, *args) -> "Standard_Real":
        r"""
        Returns the lower value of the toleranced dimension, otherwise - zero.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetUpperTolValue(self, *args)

    def GetValue(self, *args) -> "Standard_Real":
        r"""
        Returns the main dimension value. it will be the middle value in case of range dimension.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetValue(self, *args)

    def GetValues(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns raw array of dimension values.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_GetValues(self, *args)

    def HasDescriptions(self, *args) -> "Standard_Boolean":
        r"""
        Returns true, if the object has descriptions.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_HasDescriptions(self, *args)

    def HasPlane(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the object has annotation plane.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_HasPlane(self, *args)

    def HasPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true, if connection point exists (for dimesional_size), if connection point for the first shape exists (for dimensional_location).

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_HasPoint(self, *args)

    def HasPoint2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_HasPoint2(self, *args)

    def HasQualifier(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the object has dimension qualifier.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_HasQualifier(self, *args)

    def HasTextPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the position of dimension text is specified.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_HasTextPoint(self, *args)

    def IsDimWithClassOfTolerance(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the form variance was set to not xcafdimtolobjects_dimensionformvariance_none value.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_IsDimWithClassOfTolerance(self, *args)

    def IsDimWithPlusMinusTolerance(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the dimension is of +/- tolerance kind. dimension is of +/- tolerance kind if its values array contains three elements defining the main value and the lower/upper tolerances.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_IsDimWithPlusMinusTolerance(self, *args)

    def IsDimWithRange(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the dimension is of range kind. dimension is of range kind if its values array contains two elements defining lower and upper bounds.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_IsDimWithRange(self, *args)

    def NbDescriptions(self, *args) -> "Standard_Integer":
        r"""
        Returns number of descriptions.

        Returns
        -------
        int

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_NbDescriptions(self, *args)

    def RemoveDescription(self, *args) -> "void":
        r"""
        Remove description with the given number.

        Parameters
        ----------
        theNumber: int

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_RemoveDescription(self, *args)

    def SetClassOfTolerance(self, *args) -> "void":
        r"""
        Sets tolerance class of the dimension. \param thehole - true if the tolerance applies to an internal feature \param theformvariance - represents the fundamental deviation or 'position letter'  of the iso 286 limits-and-fits tolerance classification. \param thegrade - represents the quality or the accuracy grade of a tolerance.

        Parameters
        ----------
        theHole: bool
        theFormVariance: XCAFDimTolObjects_DimensionFormVariance
        theGrade: XCAFDimTolObjects_DimensionGrade

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetClassOfTolerance(self, *args)

    def SetDirection(self, *args) -> "Standard_Boolean":
        r"""
        Sets an orientation of the dimension in annotation plane.

        Parameters
        ----------
        theDir: gp_Dir

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetDirection(self, *args)

    def SetLowerBound(self, *args) -> "void":
        r"""
        Sets the lower bound of the range dimension, otherwise resets it to an empty range with the specified lower bound.

        Parameters
        ----------
        theLowerBound: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetLowerBound(self, *args)

    def SetLowerTolValue(self, *args) -> "Standard_Boolean":
        r"""
        Sets the lower value of the toleranced dimension, otherwise resets a simple dimension to toleranced one with the specified lower/upper tolerances. returns false in case of range dimension.

        Parameters
        ----------
        theLowerTolValue: float

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetLowerTolValue(self, *args)

    def SetModifiers(self, *args) -> "void":
        r"""
        Sets new sequence of dimension modifiers.

        Parameters
        ----------
        theModifiers: XCAFDimTolObjects_DimensionModifiersSequence

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetModifiers(self, *args)

    def SetNbOfDecimalPlaces(self, *args) -> "void":
        r"""
        Sets the number of places to the left and right of the decimal point respectively.

        Parameters
        ----------
        theL: int
        theR: int

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetNbOfDecimalPlaces(self, *args)

    def SetPath(self, *args) -> "void":
        r"""
        Sets a 'curve' along which the dimension is measured.

        Parameters
        ----------
        thePath: TopoDS_Edge

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetPath(self, *args)

    def SetPlane(self, *args) -> "void":
        r"""
        Sets annotation plane.

        Parameters
        ----------
        thePlane: gp_Ax2

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetPlane(self, *args)

    def SetPoint(self, *args) -> "void":
        r"""
        Set connection point (for dimesional_size), set connection point for the first shape (for dimensional_location).

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetPoint(self, *args)

    def SetPoint2(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetPoint2(self, *args)

    def SetPointTextAttach(self, *args) -> "void":
        r"""
        Sets position of the dimension text.

        Parameters
        ----------
        thePntText: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetPointTextAttach(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        Set graphical presentation for the object.

        Parameters
        ----------
        thePresentation: TopoDS_Shape
        thePresentationName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetPresentation(self, *args)

    def SetQualifier(self, *args) -> "void":
        r"""
        Sets dimension qualifier as min., max. or average.

        Parameters
        ----------
        theQualifier: XCAFDimTolObjects_DimensionQualifier

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetQualifier(self, *args)

    def SetSemanticName(self, *args) -> "void":
        r"""
        Sets semantic name.

        Parameters
        ----------
        theName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetSemanticName(self, *args)

    def SetType(self, *args) -> "void":
        r"""
        Sets a specific type of dimension.

        Parameters
        ----------
        theTyupe: XCAFDimTolObjects_DimensionType

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetType(self, *args)

    def SetUpperBound(self, *args) -> "void":
        r"""
        Sets the upper bound of the range dimension, otherwise resets it to an empty range with the specified upper bound.

        Parameters
        ----------
        theUpperBound: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetUpperBound(self, *args)

    def SetUpperTolValue(self, *args) -> "Standard_Boolean":
        r"""
        Sets the upper value of the toleranced dimension, otherwise resets a simple dimension to toleranced one with the specified lower/upper tolerances. returns false in case of range dimension.

        Parameters
        ----------
        theUperTolValue: float

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetUpperTolValue(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Sets the main dimension value. overwrites previous values.

        Parameters
        ----------
        theValue: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetValue(self, *args)

    def SetValues(self, *args) -> "void":
        r"""
        Replaces current raw array of dimension values with thevalues array.

        Parameters
        ----------
        theValue: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_SetValues(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XCAFDimTolObjects_DimensionObject_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_DimensionObject

# Register XCAFDimTolObjects_DimensionObject in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_DimensionObject_swigregister(XCAFDimTolObjects_DimensionObject)

class XCAFDimTolObjects_GeomToleranceObject(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        theObj: XCAFDimTolObjects_GeomToleranceObject

        Returns
        -------
        None

        """
        _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_GeomToleranceObject(*args))

    def AddModifier(self, *args) -> "void":
        r"""
        Adds a tolerance modifier to the sequence of modifiers.

        Parameters
        ----------
        theModifier: XCAFDimTolObjects_GeomToleranceModif

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_AddModifier(self, *args)

    def GetAffectedPlane(self, *args) -> "gp_Pln const":
        r"""
        Returns affected plane.

        Returns
        -------
        gp_Pln

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetAffectedPlane(self, *args)

    def GetAffectedPlaneType(self, *args) -> "XCAFDimTolObjects_ToleranceZoneAffectedPlane":
        r"""
        No available documentation.

        Returns
        -------
        XCAFDimTolObjects_ToleranceZoneAffectedPlane

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetAffectedPlaneType(self, *args)

    def GetAxis(self, *args) -> "gp_Ax2":
        r"""
        No available documentation.

        Returns
        -------
        gp_Ax2

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetAxis(self, *args)

    def GetMaterialRequirementModifier(self, *args) -> "XCAFDimTolObjects_GeomToleranceMatReqModif":
        r"""
        Returns material requirement of the tolerance.

        Returns
        -------
        XCAFDimTolObjects_GeomToleranceMatReqModif

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetMaterialRequirementModifier(self, *args)

    def GetMaxValueModifier(self, *args) -> "Standard_Real":
        r"""
        Returns the maximal upper tolerance.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetMaxValueModifier(self, *args)

    def GetModifiers(self, *args) -> "XCAFDimTolObjects_GeomToleranceModifiersSequence":
        r"""
        Returns a sequence of modifiers of the tolerance.

        Returns
        -------
        XCAFDimTolObjects_GeomToleranceModifiersSequence

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetModifiers(self, *args)

    def GetPlane(self, *args) -> "gp_Ax2 const":
        r"""
        Returns annotation plane.

        Returns
        -------
        gp_Ax2

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetPlane(self, *args)

    def GetPoint(self, *args) -> "gp_Pnt const":
        r"""
        Returns reference point.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetPoint(self, *args)

    def GetPointTextAttach(self, *args) -> "gp_Pnt const":
        r"""
        Returns the text position.

        Returns
        -------
        gp_Pnt

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetPointTextAttach(self, *args)

    def GetPresentation(self, *args) -> "TopoDS_Shape":
        r"""
        Returns graphical presentation of the object.

        Returns
        -------
        TopoDS_Shape

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetPresentation(self, *args)

    def GetPresentationName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns graphical presentation of the object.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetPresentationName(self, *args)

    def GetSemanticName(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns semantic name.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetSemanticName(self, *args)

    def GetType(self, *args) -> "XCAFDimTolObjects_GeomToleranceType":
        r"""
        Returns type of the object.

        Returns
        -------
        XCAFDimTolObjects_GeomToleranceType

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetType(self, *args)

    def GetTypeOfValue(self, *args) -> "XCAFDimTolObjects_GeomToleranceTypeValue":
        r"""
        Returns type of tolerance value.

        Returns
        -------
        XCAFDimTolObjects_GeomToleranceTypeValue

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetTypeOfValue(self, *args)

    def GetValue(self, *args) -> "Standard_Real":
        r"""
        Returns tolerance value.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetValue(self, *args)

    def GetValueOfZoneModifier(self, *args) -> "Standard_Real":
        r"""
        Returns value associated with tolerance zone.

        Returns
        -------
        float

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetValueOfZoneModifier(self, *args)

    def GetZoneModifier(self, *args) -> "XCAFDimTolObjects_GeomToleranceZoneModif":
        r"""
        Returns tolerance zone.

        Returns
        -------
        XCAFDimTolObjects_GeomToleranceZoneModif

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_GetZoneModifier(self, *args)

    def HasAffectedPlane(self, *args) -> "bool":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_HasAffectedPlane(self, *args)

    def HasAxis(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_HasAxis(self, *args)

    def HasPlane(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the object has annotation plane.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_HasPlane(self, *args)

    def HasPoint(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if reference point is specified.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_HasPoint(self, *args)

    def HasPointText(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if text position is specified.

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_HasPointText(self, *args)

    def SetAffectedPlane(self, *args) -> "void":
        r"""
        Sets affected plane.

        Parameters
        ----------
        thePlane: gp_Pln

        Returns
        -------
        None
        Sets affected plane.

        Parameters
        ----------
        thePlane: gp_Pln
        theType: XCAFDimTolObjects_ToleranceZoneAffectedPlane

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetAffectedPlane(self, *args)

    def SetAffectedPlaneType(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theType: XCAFDimTolObjects_ToleranceZoneAffectedPlane

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetAffectedPlaneType(self, *args)

    def SetAxis(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theAxis: gp_Ax2

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetAxis(self, *args)

    def SetMaterialRequirementModifier(self, *args) -> "void":
        r"""
        Sets material requirement of the tolerance.

        Parameters
        ----------
        theMatReqModif: XCAFDimTolObjects_GeomToleranceMatReqModif

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetMaterialRequirementModifier(self, *args)

    def SetMaxValueModifier(self, *args) -> "void":
        r"""
        Sets the maximal upper tolerance value for tolerance with modifiers.

        Parameters
        ----------
        theModifier: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetMaxValueModifier(self, *args)

    def SetModifiers(self, *args) -> "void":
        r"""
        Sets new sequence of tolerance modifiers.

        Parameters
        ----------
        theModifiers: XCAFDimTolObjects_GeomToleranceModifiersSequence

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetModifiers(self, *args)

    def SetPlane(self, *args) -> "void":
        r"""
        Sets annotation plane.

        Parameters
        ----------
        thePlane: gp_Ax2

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetPlane(self, *args)

    def SetPoint(self, *args) -> "void":
        r"""
        Sets reference point.

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetPoint(self, *args)

    def SetPointTextAttach(self, *args) -> "void":
        r"""
        Sets text position.

        Parameters
        ----------
        thePntText: gp_Pnt

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetPointTextAttach(self, *args)

    def SetPresentation(self, *args) -> "void":
        r"""
        Set graphical presentation for object.

        Parameters
        ----------
        thePresentation: TopoDS_Shape
        thePresentationName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetPresentation(self, *args)

    def SetSemanticName(self, *args) -> "void":
        r"""
        Sets semantic name.

        Parameters
        ----------
        theName: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetSemanticName(self, *args)

    def SetType(self, *args) -> "void":
        r"""
        Sets type of the object.

        Parameters
        ----------
        theType: XCAFDimTolObjects_GeomToleranceType

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetType(self, *args)

    def SetTypeOfValue(self, *args) -> "void":
        r"""
        Sets type of tolerance value.

        Parameters
        ----------
        theTypeOfValue: XCAFDimTolObjects_GeomToleranceTypeValue

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetTypeOfValue(self, *args)

    def SetValue(self, *args) -> "void":
        r"""
        Sets tolerance value.

        Parameters
        ----------
        theValue: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetValue(self, *args)

    def SetValueOfZoneModifier(self, *args) -> "void":
        r"""
        Sets value associated with tolerance zone.

        Parameters
        ----------
        theValue: float

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetValueOfZoneModifier(self, *args)

    def SetZoneModifier(self, *args) -> "void":
        r"""
        Sets tolerance zone.

        Parameters
        ----------
        theZoneModif: XCAFDimTolObjects_GeomToleranceZoneModif

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_SetZoneModifier(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_XCAFDimTolObjects_GeomToleranceObject_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_GeomToleranceObject

# Register XCAFDimTolObjects_GeomToleranceObject in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_GeomToleranceObject_swigregister(XCAFDimTolObjects_GeomToleranceObject)

class XCAFDimTolObjects_Tool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theDoc: TDocStd_Document

        Returns
        -------
        None

        """
        _XCAFDimTolObjects.XCAFDimTolObjects_Tool_swiginit(self, _XCAFDimTolObjects.new_XCAFDimTolObjects_Tool(*args))

    def GetDimensions(self, *args) -> "void":
        r"""
        Returns a sequence of dimensions currently stored in the gd&t table.

        Parameters
        ----------
        theDimensionObjectSequence: XCAFDimTolObjects_DimensionObjectSequence

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_Tool_GetDimensions(self, *args)

    def GetGeomTolerances(self, *args) -> "void":
        r"""
        Returns a sequence of tolerances currently stored in the gd&t table.

        Parameters
        ----------
        theGeomToleranceObjectSequence: XCAFDimTolObjects_GeomToleranceObjectSequence
        theDatumObjectSequence: XCAFDimTolObjects_DatumObjectSequence
        theMap: XCAFDimTolObjects_DataMapOfToleranceDatum

        Returns
        -------
        None

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_Tool_GetGeomTolerances(self, *args)

    def GetRefDatum(self, *args) -> "Standard_Boolean":
        r"""
        Returns datumobject defined for shape.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theDatum: XCAFDimTolObjects_DatumObject

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_Tool_GetRefDatum(self, *args)

    def GetRefDimensions(self, *args) -> "Standard_Boolean":
        r"""
        Returns all dimensions defined for shape.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theDimensions: XCAFDimTolObjects_DimensionObjectSequence

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_Tool_GetRefDimensions(self, *args)

    def GetRefGeomTolerances(self, *args) -> "Standard_Boolean":
        r"""
        Returns all geomtolerances defined for shape.

        Parameters
        ----------
        theShape: TopoDS_Shape
        theGeomToleranceObjectSequence: XCAFDimTolObjects_GeomToleranceObjectSequence
        theDatumObjectSequence: XCAFDimTolObjects_DatumObjectSequence
        theMap: XCAFDimTolObjects_DataMapOfToleranceDatum

        Returns
        -------
        bool

        """
        return _XCAFDimTolObjects.XCAFDimTolObjects_Tool_GetRefGeomTolerances(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _XCAFDimTolObjects.delete_XCAFDimTolObjects_Tool

# Register XCAFDimTolObjects_Tool in _XCAFDimTolObjects:
_XCAFDimTolObjects.XCAFDimTolObjects_Tool_swigregister(XCAFDimTolObjects_Tool)





